@@ -2,8 +2,8 @@
 # this repository contains the full copyright notices and license terms.
 
 from trytond.pool import Pool
-from . import stock
-from . import product
+
+from . import product, stock
 
 __all__ = ['register']
 
